==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/he/admin/hardware/form.php <==
<?php

return array(
	'bulk_delete'		=> 'אשר מחיקה גורפת של נכסים',
  'bulk_delete_help'	=> 'עיין בנכסים למחיקה בכמות גדולה בהמשך. לאחר המחיקה, ניתן לשחזר נכסים אלה, אך הם לא יהיו משויכים עוד עם משתמשים שאליהם הם מוקצים כעת.',
  'bulk_delete_warn'	=> 'אתה עומד למחוק את הנכסים: asset_count.',
	'bulk_update'		=> 'עדכון גורפת נכסים',
	'bulk_update_help'	=> 'טופס זה מאפשר לך לעדכן מספר נכסים בבת אחת. מלא רק את השדות שאתה צריך לשנות. כל השדות שנותרו ריקים יישארו ללא שינוי.',
	'bulk_update_warn'	=> 'אתה עומד לערוך את המאפיינים של: asset_count נכסים.',
    'checkedout_to'		=> 'הוצא אל',
    'checkout_date'		=> 'תבדוק את התאריך',
    'checkin_date'		=> 'תאריך הגעה',
    'checkout_to'		=> 'צא אל',
    'cost'				=> 'עלות הרכישה',
    'create'			=> 'צור נכס',
    'date'				=> 'תאריך רכישה',
    'depreciation'	    => 'פְּחָת',
    'depreciates_on'	=> 'פוחתת ב',
    'default_location'	=> 'מיקום ברירת המחדל',
    'eol_date'			=> 'תאריך EOL',
    'eol_rate'			=> 'שער EOL',
    'expected_checkin'  => 'תאריך הצ\'קין הצפוי',
    'expires'			=> 'יפוג',
    'fully_depreciated'	=> 'פוחת לחלוטין',
    'help_checkout'		=> 'אם ברצונך להקצות נכס זה באופן מיידי, בחר באפשרות "מוכן לפריסה" מרשימת הסטטוס שלמעלה.',
    'mac_address'		=> 'כתובת MAC',
    'manufacturer'		=> 'יַצרָן',
    'model'				=> 'דֶגֶם',
    'months'			=> 'חודשים',
    'name'				=> 'שם הנכס',
    'notes'				=> 'הערות',
    'order'				=> 'מספר הזמנה',
    'qr'				=> 'קוד QR',
    'requestable'		=> 'משתמשים רשאים לבקש את הנכס',
    'select_statustype'	=> 'בחר סוג סטטוס',
    'serial'			=> 'סידורי',
    'status'			=> 'סטָטוּס',
    'tag'				=> 'תג נכס',
    'update'			=> 'עדכון נכס',
    'warranty'			=> 'אַחֲרָיוּת',
		'warranty_expires'		=> 'תפוגת האחריות',
    'years'				=> 'שנים',
)
;

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/he/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'אשר מחיקה גורפת של נכסים',
  'bulk_delete_help'	=> 'עיין בנכסים למחיקה בכמות גדולה בהמשך. לאחר המחיקה, ניתן לשחזר נכסים אלה, אך הם לא יהיו משויכים עוד עם משתמשים שאליהם הם מוקצים כעת.',
  'bulk_delete_warn'	=> 'אתה עומד למחוק את הנכסים: asset_count.',
    'bulk_update'		=> 'עדכון גורפת נכסים',
    'bulk_update_help'	=> 'טופס זה מאפשר לך לעדכן מספר נכסים בבת אחת. מלא רק את השדות שאתה צריך לשנות. כל השדות שנותרו ריקים יישארו ללא שינוי.',
    'bulk_update_warn'	=> 'אתה עומד לערוך את המאפיינים של: asset_count נכסים.',
    'checkedout_to'		=> 'הוצא אל',
    'checkout_date'		=> 'תבדוק את התאריך',
    'checkin_date'		=> 'תאריך הגעה',
    'checkout_to'		=> 'צא אל',
    'cost'				=> 'עלות הרכישה',
    'create'			=> 'צור נכס',
    'date'				=> 'תאריך רכישה',
    'depreciation'	    => 'פְּחָת',
    'depreciates_on'	=> 'פוחתת ב',
    'default_location'	=> 'מיקום ברירת המחדל',
    'eol_date'			=> 'תאריך EOL',
    'eol_rate'			=> 'שער EOL',
    'expected_checkin'  => 'תאריך הצ\'קין הצפוי',
    'expires'			=> 'יפוג',
    'fully_depreciated'	=> 'פוחת לחלוטין',
    'help_checkout'		=> 'אם ברצונך להקצות נכס זה באופן מיידי, בחר באפשרות "מוכן לפריסה" מרשימת הסטטוס שלמעלה.',
    'mac_address'		=> 'כתובת MAC',
    'manufacturer'		=> 'יַצרָן',
    'model'				=> 'דֶגֶם',
    'months'			=> 'חודשים',
    'name'				=> 'שם הנכס',
    'notes'				=> 'הערות',
    'order'				=> 'מספר הזמנה',
    'qr'				=> 'קוד QR',
    'requestable'		=> 'משתמשים רשאים לבקש את הנכס',
    'select_statustype'	=> 'בחר סוג סטטוס',
    'serial'			=> 'סידורי',
    'status'			=> 'סטָטוּס',
    'tag'				=> 'תג נכס',
    'update'			=> 'עדכון נכס',
    'warranty'			=> 'אַחֲרָיוּת',
        'warranty_expires'		=> 'תפוגת האחריות',
    'years'				=> 'שנים',
    'asset_location' => 'עדכן מיקום הנכס',
    'asset_location_update_default_current' => 'עדכן מיקומים',
    'asset_location_update_default' => 'עדכן מיקום ברירת מחדל',
    'asset_not_deployable' => 'הנכס הזה לא זמין. לא ניתן לספק ללקוח.',
    'asset_deployable' => 'הנכס זמין. ניתן לשייך למיקום.',
    'processing_spinner' => 'מעבד...',
];
